async fn monitor_cocoon_health_task(state: Arc<Mutex<CocoonProcessState>>)Expand description
Background task that monitors Cocoon process health and logs crashes
async fn monitor_cocoon_health_task(state: Arc<Mutex<CocoonProcessState>>)Background task that monitors Cocoon process health and logs crashes